=================
Faster Than Light
=================


.. image:: https://img.shields.io/pypi/v/faster_than_light.svg
        :target: https://pypi.python.org/pypi/faster_than_light

.. image:: https://img.shields.io/travis/benthomasson/faster_than_light.svg
        :target: https://travis-ci.com/benthomasson/faster_than_light

.. image:: https://readthedocs.org/projects/faster-than-light/badge/?version=latest
        :target: https://faster-than-light.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Experiments in speed and scalability


* Free software: Apache Software License 2.0
* Documentation: https://faster-than-light.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
